summaryrefslogtreecommitdiff
path: root/src/server/api/endpoints/stats.ts
diff options
context:
space:
mode:
authorsyuilo <syuilotan@yahoo.co.jp>2018-04-08 02:30:37 +0900
committersyuilo <syuilotan@yahoo.co.jp>2018-04-08 02:30:37 +0900
commita1b490afa756a71b9cef4afa424575bc223bc612 (patch)
tree06de4d839e17b1e08e0891542af7360c701a154a /src/server/api/endpoints/stats.ts
parentMerge pull request #1392 from syuilo/greenkeeper/element-ui-2.3.3 (diff)
downloadmisskey-a1b490afa756a71b9cef4afa424575bc223bc612.tar.gz
misskey-a1b490afa756a71b9cef4afa424575bc223bc612.tar.bz2
misskey-a1b490afa756a71b9cef4afa424575bc223bc612.zip
Post --> Note
Closes #1411
Diffstat (limited to 'src/server/api/endpoints/stats.ts')
-rw-r--r--src/server/api/endpoints/stats.ts12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/server/api/endpoints/stats.ts b/src/server/api/endpoints/stats.ts
index 0fb0c44b0f..52e5195484 100644
--- a/src/server/api/endpoints/stats.ts
+++ b/src/server/api/endpoints/stats.ts
@@ -1,13 +1,13 @@
/**
* Module dependencies
*/
-import Post from '../../../models/post';
+import Note from '../../../models/note';
import User from '../../../models/user';
/**
* @swagger
* /stats:
- * post:
+ * note:
* summary: Show the misskey's statistics
* responses:
* 200:
@@ -15,8 +15,8 @@ import User from '../../../models/user';
* schema:
* type: object
* properties:
* postsCount:
* description: count of all posts of misskey
* type: number
* usersCount:
* description: count of all users of misskey
@@ -35,14 +35,14 @@ import User from '../../../models/user';
* @return {Promise<any>}
*/
module.exports = params => new Promise(async (res, rej) => {
- const postsCount = await Post
+ const notesCount = await Note
.count();
const usersCount = await User
.count();
res({
- postsCount: postsCount,
+ notesCount: notesCount,
usersCount: usersCount
});
});
@@ -15,8 +15,8 @@ import User from '../../../models/user';
* type: object
* properties:
- * postsCount:
- * description: count of all posts of misskey
+ * notesCount:
+ * description: count of all notes of misskey
* type: number
* usersCount: